use Test::More tests => 6;

BEGIN {
    use_ok 'Graphics::Raylib';
    use_ok 'Graphics::Raylib::Text';
    use_ok 'Graphics::Raylib::Shape';
    use_ok 'Graphics::Raylib::Texture';
    use_ok 'Graphics::Raylib::Color';
    use_ok 'Graphics::Raylib', '+family';
}
